==> carp_core-0.33.0.tar.gz: lib/carp_client/device_manager.dart <==
/*
 * Copyright 2021 Copenhagen Center for Health Technology (CACHET) at the
 * Technical University of Denmark (DTU).
 * Use of this source code is governed by a MIT-style license that can be
 * found in the LICENSE file.
 */

part of carp_core_client;

/// Collects [Data] for a single device.
abstract class DeviceDataCollector {
  /// The type of this device
  String? type;

  /// The registration for this device.
  DeviceRegistration? deviceRegistration;

  /// The description for this device.
  DeviceDescriptor? deviceDescriptor;

  /// The set of data types defining which data can be collected on this device.
  Set<String> get supportedDataTypes;

  /// Get a unique id for this device.
  String get id;

  /// Determines whether a connection can be made at this point in time to the device.
  bool canConnect();

  DeviceDataCollector([
    this.type,
    this.deviceRegistration,
    this.deviceDescriptor,
  ]);
}

/// Supports creating and holding a registry of [DeviceDataCollector]s for devices.
abstract class DeviceDataCollectorFactory {
  /// The devices available in this [DeviceDataCollectorFactory] mapped to their device type.
  Map<String, DeviceDataCollector> get devices;

  /// Returns the [DeviceDataCollector] of the given [deviceType].
  /// Returns `null` if no device is found.
  DeviceDataCollector? getDevice(String deviceType);

  /// Returns true if this factory supports a device of the given [deviceType].
  /// Note that even though a certain type of device is supported, its device
  /// [DeviceDataCollector] is not loaded until [registerDevice] is called.
  bool supportsDevice(String deviceType);

  /// Returns true if this factory contain a device manager of the given [deviceType].
  bool hasDevice(String deviceType);

  /// Register and initialize a [DeviceDataCollector] for a [deviceType].
  void registerDevice(String deviceType, DeviceDataCollector collector);

  /// Create and register a [DeviceDataCollector] based on a [deviceType].
  /// Returns `null` if a device cannot be created.
  Future<DeviceDataCollector?> createDevice(String deviceType);

  // Remove the device of [deviceType] from this registry.
  void unregisterDevice(String deviceType);

  /// Initialize all devices in a [masterDeviceDeployment].
  void initializeDevices(MasterDeviceDeployment masterDeviceDeployment);

  /// Initialize the is the device [descriptor].
  void initializeDevice(DeviceDescriptor descriptor);
}

==> carp_core-0.40.8.tar.gz: lib/carp_client/device_manager.dart <==
/*
 * Copyright 2021-2022 Copenhagen Center for Health Technology (CACHET) at the
 * Technical University of Denmark (DTU).
 * Use of this source code is governed by a MIT-style license that can be
 * found in the LICENSE file.
 */

part of carp_core_client;

/// Collects [Data] for a single device.
abstract class DeviceDataCollector<TDeviceRegistration, TDeviceDescriptor> {
  /// The type of this device
  String? type;

  /// The registration for this device.
  TDeviceRegistration? deviceRegistration;

  /// The description for this device.
  TDeviceDescriptor? deviceDescriptor;

  /// The set of data types defining which data can be collected on this device.
  Set<String> get supportedDataTypes;

  /// Get a unique id for this device.
  String get id;

  /// Determines whether a connection can be made at this point in time to
  /// the device.
  Future<bool> canConnect();

  DeviceDataCollector([
    this.type,
    this.deviceRegistration,
    this.deviceDescriptor,
  ]);
}

/// Supports creating and holding a registry of [DeviceDataCollector]s for devices.
abstract class DeviceDataCollectorFactory {
  /// The devices available in this [DeviceDataCollectorFactory] mapped to their
  /// device type.
  Map<String, DeviceDataCollector> get devices;

  /// Returns the [DeviceDataCollector] of the given [deviceType].
  /// Returns `null` if no device is found.
  DeviceDataCollector? getDevice(String deviceType);

  /// Returns true if this factory supports a device of the given [deviceType].
  /// Note that even though a certain type of device is supported, its device
  /// [DeviceDataCollector] is not loaded until [registerDevice] is called.
  bool supportsDevice(String deviceType);

  /// Returns true if this factory contain a device manager of the given [deviceType].
  bool hasDevice(String deviceType);

  /// Register and initialize a [DeviceDataCollector] for a [deviceType].
  void registerDevice(String deviceType, DeviceDataCollector collector);

  /// Create and register a [DeviceDataCollector] based on a [deviceType].
  /// Returns `null` if a device cannot be created.
  Future<DeviceDataCollector?> createDevice(String deviceType);

  // Remove the device of [deviceType] from this registry.
  void unregisterDevice(String deviceType);

  /// Initialize all devices in a [masterDeviceDeployment].
  void initializeDevices(MasterDeviceDeployment masterDeviceDeployment);

  /// Initialize the device specified in the [descriptor].
  void initializeDevice(DeviceDescriptor descriptor);
}
